# packages.sh
#export PKG_<SCRIPTNAME>=<pkg URL>

export PKG_GHOSTSCRIPT=https://github.com/ArtifexSoftware/ghostpdl-downloads/releases/download/gs10051/ghostscript-10.05.1.tar.xz
export PKG_GHOSTSCRIPT_FONTS_STD=https://downloads.sourceforge.net/gs-fonts/ghostscript-fonts-std-8.11.tar.gz
export PKG_GHOSTSCRIPT_FONTS_OTHER=https://downloads.sourceforge.net/gs-fonts/gnu-gs-fonts-other-6.0.tar.gz
export PATCH_GHOSTSCRIPT=https://www.linuxfromscratch.org/patches/blfs/12.4/ghostscript-10.05.1-gcc15_fixes-1.patch